pub fn create_processor() -> BundleProcessorExpand description
Convenience functions for common operations Create a bundle processor with default settings
pub fn create_processor() -> BundleProcessorConvenience functions for common operations Create a bundle processor with default settings