pub fn load_bundle<P: AsRef<Path>>(path: P) -> Result<AssetBundle>Expand description
Convenience functions for quick bundle loading Load a single bundle from file
pub fn load_bundle<P: AsRef<Path>>(path: P) -> Result<AssetBundle>Convenience functions for quick bundle loading Load a single bundle from file