Bundle parser implementation
This module provides the main parsing logic for Unity AssetBundles, inspired by UnityPy/files/BundleFile.py
Structs
- Bundle
Parser - Main bundle parser
- Parsing
Complexity - Parsing complexity information
Bundle parser implementation
This module provides the main parsing logic for Unity AssetBundles, inspired by UnityPy/files/BundleFile.py