AssetBundle

Struct AssetBundle 

pub struct AssetBundle {
    pub header: BundleHeader,
    pub blocks: Vec<CompressionBlock>,
    pub nodes: Vec<DirectoryNode>,
    pub files: Vec<BundleFileInfo>,
    pub assets: Vec<Asset>,
    pub asset_names: Vec<String>,
    /* private fields */
}
A Unity AssetBundle

This structure represents a complete Unity AssetBundle with all its metadata, compression information, and contained assets.

Fields

header: BundleHeader

Bundle header

blocks: Vec<CompressionBlock>

Compression blocks

nodes: Vec<DirectoryNode>

Directory nodes

files: Vec<BundleFileInfo>

File information

assets: Vec<Asset>

Contained assets

asset_names: Vec<String>

Asset file names within the bundle (aligned with assets indices).

Implementations

Source

impl AssetBundle

pub fn new(header: BundleHeader, data: Vec<u8>) -> Self

Create a new AssetBundle

pub fn data_checked(&self) -> Result<&[u8]>

Get the decompressed bundle data, decompressing UnityFS blocks on demand.

pub fn data(&self) -> &[u8]

Get the raw bundle data if already decompressed, otherwise returns an empty slice.

pub fn data_arc(&self) -> Result<Arc<[u8]>>

Get a shared reference to the decompressed bundle data, decompressing on demand.

pub fn size(&self) -> u64

Get the total size of the bundle

pub fn is_compressed(&self) -> bool

Check if the bundle is compressed

pub fn file_count(&self) -> usize

Get the number of files in the bundle

pub fn asset_count(&self) -> usize

Get the number of assets in the bundle

pub fn find_file(&self, name: &str) -> Option<&BundleFileInfo>

Find a file by name

pub fn find_node(&self, name: &str) -> Option<&DirectoryNode>

Find a node by name

pub fn file_names(&self) -> Vec<&str>

Get all file names

pub fn node_names(&self) -> Vec<&str>

Get all node names

pub fn extract_file_data(&self, file: &BundleFileInfo) -> Result<Vec<u8>>

Extract data for a specific file

pub fn extract_file_slice(&self, file: &BundleFileInfo) -> Result<&[u8]>

pub fn extract_node_data(&self, node: &DirectoryNode) -> Result<Vec<u8>>

Extract data for a specific node

pub fn extract_node_slice(&self, node: &DirectoryNode) -> Result<&[u8]>

pub fn statistics(&self) -> BundleStatistics

Get bundle statistics

pub fn validate(&self) -> Result<()>

Validate bundle consistency