pub fn load_bundle_file_with_options<P: AsRef<Path>>(
path: P,
options: BundleLoadOptions,
) -> Result<AssetBundle>Expand description
Load an AssetBundle from a filesystem path with explicit parser options.
pub fn load_bundle_file_with_options<P: AsRef<Path>>(
path: P,
options: BundleLoadOptions,
) -> Result<AssetBundle>Load an AssetBundle from a filesystem path with explicit parser options.