Texture2D converter and processor
This module provides the main conversion logic for Unity Texture2D objects. Inspired by UnityPy/export/Texture2DConverter.py
Structs
- Texture2D
Converter - Main texture converter
Texture2D converter and processor
This module provides the main conversion logic for Unity Texture2D objects. Inspired by UnityPy/export/Texture2DConverter.py