TypeTreeSerializer

Struct TypeTreeSerializer 

pub struct TypeTreeSerializer<'a> { /* private fields */ }
TypeTree serializer

This struct provides methods for serializing and deserializing Unity objects using TypeTree structure information.

Implementations

Source

impl<'a> TypeTreeSerializer<'a>

pub fn new(tree: &'a TypeTree) -> Self

Create a new serializer with a TypeTree

pub fn parse_object( &self, reader: &mut BinaryReader<'_>, ) -> Result<IndexMap<String, UnityValue>>

Parse object data using the TypeTree structure

pub fn parse_object_with_ref_types( &self, reader: &mut BinaryReader<'_>, ref_types: &'a [SerializedType], ) -> Result<IndexMap<String, UnityValue>>

pub fn parse_object_detailed( &self, reader: &mut BinaryReader<'_>, options: TypeTreeParseOptions, ) -> Result<TypeTreeParseOutput>

pub fn parse_object_detailed_with_ref_types( &self, reader: &mut BinaryReader<'_>, options: TypeTreeParseOptions, ref_types: &'a [SerializedType], ) -> Result<TypeTreeParseOutput>

pub fn parse_object_prefix_detailed( &self, reader: &mut BinaryReader<'_>, options: TypeTreeParseOptions, root_children: usize, ) -> Result<TypeTreeParseOutput>

Parse only the first root_children fields of the root node.

This enables UnityPy-like fast paths such as peek_name() where we only need a small prefix of the TypeTree to reach m_Name.

pub fn parse_object_prefix_detailed_with_ref_types( &self, reader: &mut BinaryReader<'_>, options: TypeTreeParseOptions, root_children: usize, ref_types: &'a [SerializedType], ) -> Result<TypeTreeParseOutput>

pub fn scan_pptrs( &self, reader: &mut BinaryReader<'_>, ) -> Result<PPtrScanResult>

Scan TypeTree-based object bytes and collect any encountered PPtr references without allocating a full UnityValue tree.

pub fn scan_pptrs_with_ref_types( &self, reader: &mut BinaryReader<'_>, ref_types: Option<&[SerializedType]>, ) -> Result<PPtrScanResult>

Scan TypeTree-based object bytes and collect any encountered PPtr references, using file-level ref_types to best-effort traverse managed reference payloads.

pub fn serialize_object( &self, data: &IndexMap<String, UnityValue>, ) -> Result<Vec<u8>>

Serialize object data using the TypeTree structure

pub fn tree(&self) -> &TypeTree

Get the TypeTree being used

pub fn estimate_size(&self, data: &IndexMap<String, UnityValue>) -> usize

Estimate serialized size